@@ -33,8 +33,6 @@ pub struct ParserConfig {
 #[derive(Debug, Default, Clone, Copy)]
 struct Ctx {
     allow_operation_in_value: bool,
-    allow_separating_value_with_space: bool,
-    allow_separating_value_with_comma: bool,
 
     allow_at_selector: bool,
 
